# My Package

My Package is a Python package for doing something useful.

## Installation

You can install My Package using pip:

settings.py

```bash
CLICKUP_PERSONAL_API_KEY = config("CLICKUP_PERSONAL_API_KEY")
CLICKUP_SHOPS_LIST_ID = "900202095660"
CLICKUP_CONTACTS_LIST_ID = 900202095665
CLICKUP_APP_SHOPS_LIST_ID = 900202127359
CRM_APP_NAME = "test"

KLAVIYO_PUBLIC_API_KEY = config("KLAVIYO_PUBLIC_API_KEY")
KLAVIYO_SECRET_API_KEY = config("KLAVIYO_SECRET_API_KEY")
```
